DropDownItemSearchable class abstract interface

An interface that allows the datatype of DropDownItem.data to determine the default search implementation.

Gets overridden by DropDownOptions.searchDelegate.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
satisfiesSearch(String query) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited