ff_drop_down_list library
Provides a customizable drop down modal.
Classes
-
DropDown<
T> - Manages the state and behavior of a dropdown.
-
DropDownBody<
T> - This is the dropdown widget that will be displayed in the bottom sheet body.
-
DropDownData<
T> - Manages the data of a dropdown.
-
DropDownItem<
T> - This is a model class used to represent an item in a selectable list.
- DropDownItemBuilder
- An interface that allows the datatype of DropDownItem.data to determine how the drop down displays an item by default.
- DropDownItemSearchable
- An interface that allows the datatype of DropDownItem.data to determine the default search implementation.
-
DropDownOptions<
T> - Manages the options and behavior of a dropdown.
-
DropDownResponse<
T> - The response returned from a drop down.
- DropDownStyle
- Manages the style and appearance of a dropdown.
Extensions
-
DropDownListExtensions
on DropDownList<
T> - Operations for lists of DropDownItems (DropDownList)
-
ListAsDropDownItems
on List<
T> - Adds a method to convert a list into a list of DropDownItems.
Typedefs
- BottomSheetListener = bool Function(DraggableScrollableNotification notification)
- A function type definition for handling notifications from a draggable bottom sheet.
-
DropDownList<
T> = List< DropDownItem< T> > - An alias for a List of DropDownItems.
- DropDownStyleBuilder = DropDownStyle Function(BuildContext context)
- A function type definition for building a DropDownStyle.
- EmptySearchResultsTextBuilder = String Function(String query, int count)
- A function type definition for building the text to display when search returns no results.
- EmptySearchResultsWidgetBuilder = Widget Function(String query, int count)
- A function type definition for building a widget to display when search returns no results.
-
ItemSelectedCallback<
T> = void Function(DropDownList< T> items) - A callback function that is invoked when items are selected.
-
ListItemBuilder<
T> = Widget Function(int index, DropDownItem< T> item) - A function type definition for building a widget for a specific list item.
- ListViewListener = bool Function(ScrollNotification notification)
- A function type definition for handling scroll notifications from the list view.
-
MultipleItemSelectedCallback<
T> = void Function(DropDownList< T> items) - A callback function that is invoked when multiple items are selected.
-
SearchDelegate<
T> = DropDownList< T> Function(String query, DropDownList<T> items) - A function type definition for searching through a list of items based on the user's query.
-
SingleItemSelectedCallback<
T> = void Function(DropDownItem< T> item) - A callback function that is invoked when a single item is selected.
-
SortDelegate<
T> = int Function(DropDownItem< T> a, DropDownItem<T> b) - A function type definition for sorting through the list of items.