model/contextual_colors library
Provides colors that can change depending on the current BuildContext.
Classes
- BrightnessColor
- Allows for a color to change depending on the Brightness of the theme for the current BuildContext.
- ContextualColor
- Allows for a color to change depending on the current BuildContext.
- ThemedColor
- Allows for a color to change depending on the ThemeData of the current BuildContext.
Extensions
- ColorToArgb32 on Color
- Adds the toARGB32 method to Color which gets added to the Flutter SDK in version 3.29
- ContextualizeColors on Color
- Provides the contextualize method which runs ContextualProperty.resolveAs.
- ContextualizeNullableColors on Color?
- Provides the contextualize method which runs ContextualProperty.resolveAs.
- InvertColors on Color
- Provides the inverted getter to invert a color.